@@ -1,8 +1,8 @@
 
-#' R6 Class Representing PriorBSVAR-MSH
+#' R6 Class Representing PriorBSVARMSH
 #'
 #' @description
-#' The class PriorBSVAR-MSH presents a prior specification for the bsvar model with Markov Switching Heteroskedasticity.
+#' The class PriorBSVARMSH presents a prior specification for the bsvar model with Markov Switching Heteroskedasticity.
 #' 
 #' @examples 
 #' prior = specify_prior_bsvar_msh$new(N = 3, p = 1, M = 2)  # specify the prior
@@ -10,7 +10,7 @@
 #' 
 #' @export
 specify_prior_bsvar_msh = R6::R6Class(
-  "PriorBSVAR-MSH",
+  "PriorBSVARMSH",
   
   inherit = specify_prior_bsvar,
   
@@ -28,17 +28,37 @@ specify_prior_bsvar_msh = R6::R6Class(
     #' @field B_nu a positive integer greater of equal than \code{N}, a shape parameter of the generalised-normal prior distribution for the structural matrix \eqn{B}.
     B_nu       = NA,
     
-    #' @field hyper_nu a positive scalar, the shape parameter of the inverted-gamma 2 prior distribution for the two overall shrinkage parameters for matrices \eqn{B} and \eqn{A}.
-    hyper_nu   = NA,
+    #' @field hyper_nu_B a positive scalar, the shape parameter of the inverted-gamma 2 prior
+    #' for the overall shrinkage parameter for matrix \eqn{B}.
+    hyper_nu_B = NA,
     
-    #' @field hyper_a a positive scalar, the shape parameter of the gamma prior for the two overall shrinkage parameters.
-    hyper_a    = NA,
+    #' @field hyper_a_B a positive scalar, the shape parameter of the gamma prior
+    #' for the second-level hierarchy for the overall shrinkage parameter for matrix \eqn{B}.
+    hyper_a_B  = NA,
     
-    #' @field hyper_V a positive scalar,  the shape parameter of the inverted-gamma 2 for the level 3 hierarchy of shrinkage parameters.
-    hyper_V    = NA,
+    #' @field hyper_s_BB a positive scalar, the scale parameter of the inverted-gamma 2 prior
+    #' for the third-level of hierarchy for overall shrinkage parameter for matrix \eqn{B}.
+    hyper_s_BB  = NA,
     
-    #' @field hyper_S a positive scalar,  the scale parameter of the inverted-gamma 2 for the level 3 hierarchy of shrinkage parameters.
-    hyper_S    = NA,
+    #' @field hyper_nu_BB a positive scalar, the shape parameter of the inverted-gamma 2 prior
+    #' for the third-level of hierarchy for overall shrinkage parameter for matrix \eqn{B}.
+    hyper_nu_BB  = NA,
+    
+    #' @field hyper_nu_A a positive scalar, the shape parameter of the inverted-gamma 2 prior 
+    #' for the overall shrinkage parameter for matrix \eqn{A}.
+    hyper_nu_A  = NA,
+    
+    #' @field hyper_a_A a positive scalar, the shape parameter of the gamma prior
+    #' for the second-level hierarchy for the overall shrinkage parameter for matrix \eqn{A}.
+    hyper_a_A  = NA,
+    
+    #' @field hyper_s_AA a positive scalar, the scale parameter of the inverted-gamma 2 prior
+    #' for the third-level of hierarchy for overall shrinkage parameter for matrix \eqn{A}.
+    hyper_s_AA  = NA,
+    
+    #' @field hyper_nu_AA a positive scalar, the shape parameter of the inverted-gamma 2 prior
+    #' for the third-level of hierarchy for overall shrinkage parameter for matrix \eqn{A}.
+    hyper_nu_AA  = NA,
     
     #' @field sigma_nu a positive scalar,  the shape parameter of the inverted-gamma 2 for MS state-dependent variances of the structural shocks, \eqn{\sigma^2_{n.s_t}}.
     sigma_nu   = 3,
@@ -50,12 +70,12 @@ specify_prior_bsvar_msh = R6::R6Class(
     PR_TR      = matrix(),
     
     #' @description
-    #' Create a new prior specification PriorBSVAR-MSH.
+    #' Create a new prior specification PriorBSVARMSH.
     #' @param N a positive integer - the number of dependent variables in the model.
     #' @param p a positive integer - the autoregressive lag order of the SVAR model.
     #' @param M an integer greater than 1 - the number of Markov process' heteroskedastic regimes.
     #' @param stationary an \code{N} logical vector - its element set to \code{FALSE} sets the prior mean for the autoregressive parameters of the \code{N}th equation to the white noise process, otherwise to random walk.
-    #' @return A new prior specification PriorBSVAR-MSH.
+    #' @return A new prior specification PriorBSVARMSH.
     initialize = function(N, p, M, stationary = rep(FALSE, N)){
       stopifnot("Argument N must be a positive integer number." = N > 0 & N %% 1 == 0)
       stopifnot("Argument p must be a positive integer number." = p > 0 & p %% 1 == 0)
@@ -70,7 +90,7 @@ specify_prior_bsvar_msh = R6::R6Class(
     }, # END initialize
     
     #' @description
-    #' Returns the elements of the prior specification PriorBSVAR-MSH as a \code{list}.
+    #' Returns the elements of the prior specification PriorBSVARMSH as a \code{list}.
     #' 
     #' @examples 
     #' # a prior for 3-variable example with four lags and two regimes
@@ -83,10 +103,14 @@ specify_prior_bsvar_msh = R6::R6Class(
         A_V_inv  = self$A_V_inv,
         B_V_inv  = self$B_V_inv,
         B_nu     = self$B_nu,
-        hyper_nu = self$hyper_nu,
-        hyper_a  = self$hyper_a,
-        hyper_V  = self$hyper_V,
-        hyper_S  = self$hyper_S,
+        hyper_nu_B  = self$hyper_nu_B,
+        hyper_a_B   = self$hyper_a_B,
+        hyper_s_BB  = self$hyper_s_BB,
+        hyper_nu_BB = self$hyper_nu_BB,
+        hyper_nu_A  = self$hyper_nu_A,
+        hyper_a_A   = self$hyper_a_A,
+        hyper_s_AA  = self$hyper_s_AA,
+        hyper_nu_AA = self$hyper_nu_AA,
         sv_a_    = self$sv_a_,
         sv_s_    = self$sv_s_,
         sigma_nu = self$sigma_nu,
@@ -101,10 +125,10 @@ specify_prior_bsvar_msh = R6::R6Class(
 
 
 
-#' R6 Class Representing StartingValuesBSVAR-MSH
+#' R6 Class Representing StartingValuesBSVARMSH
 #'
 #' @description
-#' The class StartingValuesBSVAR-MSH presents starting values for the bsvar model with Markov Switching Heteroskedasticity.
+#' The class StartingValuesBSVARMSH presents starting values for the bsvar model with Markov Switching Heteroskedasticity.
 #' 
 #' @examples 
 #' # starting values for a bsvar model for a 3-variable system
@@ -112,7 +136,7 @@ specify_prior_bsvar_msh = R6::R6Class(
 #' 
 #' @export
 specify_starting_values_bsvar_msh = R6::R6Class(
-  "StartingValuesBSVAR-MSH",
+  "StartingValuesBSVARMSH",
   
   inherit = specify_starting_values_bsvar,
   
@@ -124,8 +148,9 @@ specify_starting_values_bsvar_msh = R6::R6Class(
     #' @field B an \code{NxN} matrix of starting values for the parameter \eqn{B}. 
     B             = matrix(),
     
-    #' @field hyper a \code{5}-vector of starting values for the shrinkage hyper-parameters of the hierarchical prior distribution. 
-    hyper         = numeric(),
+    #' @field hyper a \code{(2*N+1)x2} matrix of starting values for the shrinkage hyper-parameters of the 
+    #' hierarchical prior distribution. 
+    hyper         = matrix(),
     
     #' @field sigma2 an \code{NxM} matrix of starting values for the MS state-specific variances of the structural shocks. Its elements sum to value \code{M} over the rows.
     sigma2        = matrix(),
@@ -188,9 +213,9 @@ specify_starting_values_bsvar_msh = R6::R6Class(
     }, # END get_starting_values
     
     #' @description
-    #' Returns the elements of the starting values StartingValuesBSVAR-MSH as a \code{list}.
+    #' Returns the elements of the starting values StartingValuesBSVARMSH as a \code{list}.
     #' @param last_draw a list containing the last draw.
-    #' @return An object of class StartingValuesBSVAR-MS including the last draw of the current MCMC as the starting value to be passed to the continuation of the MCMC estimation using \code{bsvar_msh()}.
+    #' @return An object of class StartingValuesBSVAR-MS including the last draw of the current MCMC as the starting value to be passed to the continuation of the MCMC estimation using \code{estimate()}.
     #' 
     #' @examples 
     #' # starting values for a bsvar model with 1 lag for a 3-variable system
@@ -219,9 +244,9 @@ specify_starting_values_bsvar_msh = R6::R6Class(
 #' R6 Class representing the specification of the BSVAR model with Markov Switching Heteroskedasticity.
 #'
 #' @description
-#' The class BSVAR-MSH presents complete specification for the BSVAR model with Markov Switching Heteroskedasticity.
+#' The class BSVARMSH presents complete specification for the BSVAR model with Markov Switching Heteroskedasticity.
 #' 
-#' @seealso \code{\link{estimate_bsvar_msh}}, \code{\link{specify_posterior_bsvar_msh}}
+#' @seealso \code{\link{estimate}}, \code{\link{specify_posterior_bsvar_msh}}
 #' 
 #' @examples 
 #' data(us_fiscal_lsuw)
@@ -233,7 +258,7 @@ specify_starting_values_bsvar_msh = R6::R6Class(
 #' 
 #' @export
 specify_bsvar_msh = R6::R6Class(
-  "BSVAR-MSH",
+  "BSVARMSH",
   
   public = list(
     
@@ -243,27 +268,27 @@ specify_bsvar_msh = R6::R6Class(
     #' @field identification an object IdentificationBSVARs with the identifying restrictions. 
     identification         = list(),
     
-    #' @field prior an object PriorBSVAR-MSH with the prior specification. 
+    #' @field prior an object PriorBSVARMSH with the prior specification. 
     prior                  = list(),
     
     #' @field data_matrices an object DataMatricesBSVAR with the data matrices.
     data_matrices          = list(),
     
-    #' @field starting_values an object StartingValuesBSVAR-MSH with the starting values.
+    #' @field starting_values an object StartingValuesBSVARMSH with the starting values.
     starting_values        = list(),
     
     #' @field finiteM a logical value - if true a stationary Markov switching model is estimated. Otherwise, a sparse Markov switching model is estimated in which \code{M=20} and the number of visited states is estimated.
     finiteM                = logical(),
     
     #' @description
-    #' Create a new specification of the BSVAR model with Markov Switching Heteroskedasticity, BSVAR-MSH.
+    #' Create a new specification of the BSVAR model with Markov Switching Heteroskedasticity, BSVARMSH.
     #' @param data a \code{(T+p)xN} matrix with time series data.
     #' @param p a positive integer providing model's autoregressive lag order.
     #' @param M an integer greater than 1 - the number of Markov process' heteroskedastic regimes.
     #' @param B a logical \code{NxN} matrix containing value \code{TRUE} for the elements of the structural matrix \eqn{B} to be estimated and value \code{FALSE} for exclusion restrictions to be set to zero.
     #' @param stationary an \code{N} logical vector - its element set to \code{FALSE} sets the prior mean for the autoregressive parameters of the \code{N}th equation to the white noise process, otherwise to random walk.
     #' @param finiteM a logical value - if true a stationary Markov switching model is estimated. Otherwise, a sparse Markov switching model is estimated in which \code{M=20} and the number of visited states is estimated.
-    #' @return A new complete specification for the bsvar model with Markov Switching Heteroskedasticity, BSVAR-MSH.
+    #' @return A new complete specification for the bsvar model with Markov Switching Heteroskedasticity, BSVARMSH.
     initialize = function(
     data,
     p = 1L,
@@ -331,7 +356,7 @@ specify_bsvar_msh = R6::R6Class(
     }, # END get_identification
     
     #' @description
-    #' Returns the prior specification as the PriorBSVAR-MSH object.
+    #' Returns the prior specification as the PriorBSVARMSH object.
     #' 
     #' @examples 
     #' data(us_fiscal_lsuw)
@@ -347,7 +372,7 @@ specify_bsvar_msh = R6::R6Class(
     }, # END get_prior
     
     #' @description
-    #' Returns the starting values as the StartingValuesBSVAR-MSH object.
+    #' Returns the starting values as the StartingValuesBSVARMSH object.
     #' 
     #' @examples 
     #' data(us_fiscal_lsuw)
@@ -367,27 +392,27 @@ specify_bsvar_msh = R6::R6Class(
 
 
 
-#' R6 Class Representing PosteriorBSVAR-MSH
+#' R6 Class Representing PosteriorBSVARMSH
 #'
 #' @description
-#' The class PosteriorBSVAR-MSH contains posterior output and the specification including 
+#' The class PosteriorBSVARMSH contains posterior output and the specification including 
 #' the last MCMC draw for the bsvar model with Markov Switching Heteroskedasticity. 
 #' Note that due to the thinning of the MCMC output the starting value in element \code{last_draw}
 #' might not be equal to the last draw provided in element \code{posterior}.
 #' 
-#' @seealso \code{\link{estimate_bsvar_msh}}, \code{\link{specify_bsvar_msh}}
+#' @seealso \code{\link{estimate}}, \code{\link{specify_bsvar_msh}}
 #' 
 #' @examples 
-#' # This is a function that is used within estimate_bsvar()
+#' # This is a function that is used within estimate()
 #' data(us_fiscal_lsuw)
 #' specification  = specify_bsvar_msh$new(us_fiscal_lsuw, p = 4, M = 2)
 #' set.seed(123)
-#' estimate       = estimate_bsvar_msh(10, specification, thin = 1)
+#' estimate       = estimate(specification, 10, thin = 1)
 #' class(estimate)
 #' 
 #' @export
 specify_posterior_bsvar_msh = R6::R6Class(
-  "PosteriorBSVAR-MSH",
+  "PosteriorBSVARMSH",
   
   private = list(
     normalised = FALSE
@@ -395,21 +420,21 @@ specify_posterior_bsvar_msh = R6::R6Class(
   
   public = list(
     
-    #' @field last_draw an object of class BSVAR-MSH with the last draw of the current MCMC run as the starting value to be passed to the continuation of the MCMC estimation using \code{bsvar_msh()}. 
+    #' @field last_draw an object of class BSVARMSH with the last draw of the current MCMC run as the starting value to be passed to the continuation of the MCMC estimation using \code{estimate()}. 
     last_draw = list(),
     
     #' @field posterior a list containing Bayesian estimation output.
     posterior = list(),
     
     #' @description
-    #' Create a new posterior output PosteriorBSVAR-MSH.
-    #' @param specification_bsvar an object of class BSVAR-MSH with the last draw of the current MCMC run as the starting value.
+    #' Create a new posterior output PosteriorBSVARMSH.
+    #' @param specification_bsvar an object of class BSVARMSH with the last draw of the current MCMC run as the starting value.
     #' @param posterior_bsvar a list containing Bayesian estimation output.
-    #' @return A posterior output PosteriorBSVAR-MSH.
+    #' @return A posterior output PosteriorBSVARMSH.
     initialize = function(specification_bsvar, posterior_bsvar) {
       
-      stopifnot("Argument specification_bsvar must be of class BSVAR-MSH." = any(class(specification_bsvar) == "BSVAR-MSH"))
-      stopifnot("Argument posterior_bsvar must must contain MCMC output." = is.list(posterior_bsvar) & is.array(posterior_bsvar$B) & is.array(posterior_bsvar$A) & is.matrix(posterior_bsvar$hyper) & is.array(posterior_bsvar$xi))
+      stopifnot("Argument specification_bsvar must be of class BSVARMSH." = any(class(specification_bsvar) == "BSVARMSH"))
+      stopifnot("Argument posterior_bsvar must must contain MCMC output." = is.list(posterior_bsvar) & is.array(posterior_bsvar$B) & is.array(posterior_bsvar$A) & is.array(posterior_bsvar$hyper) & is.array(posterior_bsvar$xi))
       
       self$last_draw    = specification_bsvar
       self$posterior    = posterior_bsvar
@@ -422,7 +447,7 @@ specify_posterior_bsvar_msh = R6::R6Class(
     #' data(us_fiscal_lsuw)
     #' specification  = specify_bsvar_msh$new(us_fiscal_lsuw, M = 2)
     #' set.seed(123)
-    #' estimate       = estimate_bsvar_msh(10, specification, thin = 1)
+    #' estimate       = estimate(specification, 10, thin = 1)
     #' estimate$get_posterior()
     #' 
     get_posterior       = function(){
@@ -430,7 +455,7 @@ specify_posterior_bsvar_msh = R6::R6Class(
     }, # END get_posterior
     
     #' @description
-    #' Returns an object of class BSVAR-MSH with the last draw of the current MCMC run as the starting value to be passed to the continuation of the MCMC estimation using \code{bsvar_msh()}.
+    #' Returns an object of class BSVARMSH with the last draw of the current MCMC run as the starting value to be passed to the continuation of the MCMC estimation using \code{estimate()}.
     #' 
     #' @examples
     #' data(us_fiscal_lsuw)
@@ -440,13 +465,10 @@ specify_posterior_bsvar_msh = R6::R6Class(
     #' 
     #' # run the burn-in
     #' set.seed(123)
-    #' burn_in        = estimate_bsvar_msh(10, specification, thin = 2)
-    #' 
-    #' # get the last draw
-    #' last_draw      = burn_in$get_last_draw()
+    #' burn_in        = estimate(specification, 10, thin = 2)
     #' 
     #' # estimate the model
-    #' posterior      = estimate_bsvar_msh(10, last_draw, thin = 2)
+    #' posterior      = estimate(burn_in, 10, thin = 2)
     #' 
     get_last_draw      = function(){
       self$last_draw$clone()
@@ -464,15 +486,15 @@ specify_posterior_bsvar_msh = R6::R6Class(
     #' 
     #' # estimate the model
     #' set.seed(123)
-    #' posterior      = estimate_bsvar_msh(10, specification, thin = 1)
+    #' posterior      = estimate(specification, 10, thin = 1)
     #' 
     #' # check normalisation status beforehand
     #' posterior$is_normalised()
     #' 
     #' # normalise the posterior
     #' BB            = posterior$last_draw$starting_values$B      # get the last draw of B
-    #' B_hat         = diag(sign(diag(BB))) %*% BB                # set positive diagonal elements
-    #' bsvars::normalise_posterior(posterior, B_hat)              # draws in posterior are normalised
+    #' B_hat         = diag((-1) * sign(diag(BB))) %*% BB         # set negative diagonal elements
+    #' normalise_posterior(posterior, B_hat)                      # draws in posterior are normalised
     #' 
     #' # check normalisation status afterwards
     #' posterior$is_normalised()
@@ -497,7 +519,7 @@ specify_posterior_bsvar_msh = R6::R6Class(
     #' set.seed(123)
     #' 
     #' # estimate the model
-    #' posterior      = estimate_bsvar(10, specification, thin = 1)
+    #' posterior      = estimate(specification, 10, thin = 1)
     #' 
     #' # check normalisation status beforehand
     #' posterior$is_normalised()
@@ -505,7 +527,7 @@ specify_posterior_bsvar_msh = R6::R6Class(
     #' # normalise the posterior
     #' BB            = posterior$last_draw$starting_values$B      # get the last draw of B
     #' B_hat         = diag(sign(diag(BB))) %*% BB                # set positive diagonal elements
-    #' bsvars::normalise_posterior(posterior, B_hat)              # draws in posterior are normalised
+    #' normalise_posterior(posterior, B_hat)                      # draws in posterior are normalised
     #' 
     #' # check normalisation status afterwards
     #' posterior$is_normalised()
