@@ -52,6 +52,7 @@ Rcpp::List svar_nc1 (
     arma::rowvec&   aux_h_n,              // 1xT
     double&         aux_rho_n,
     double&         aux_omega_n,
+    double&         aux_sigma2v_n,
     double&         aux_sigma2_omega_n,   // omega prior hyper-parameter 
     double&         aux_s_n,              // scale of IG2 prior for aux_sigma2_omega_n
     arma::urowvec&  aux_S_n,              // 1xT
@@ -60,4 +61,17 @@ Rcpp::List svar_nc1 (
     bool            sample_s_ = true
 );
 
+Rcpp::List svar_ce1 (
+    arma::rowvec&       aux_h_n,            // 1xT
+    double&             aux_rho_n,
+    double&             aux_omega_n,
+    double&             aux_sigma2v_n,
+    double&             aux_sigma2_omega_n, // omega prior hyper-parameter 
+    double&             aux_s_n,             // scale of IG2 prior for aux_sigma2_omega_n
+    arma::urowvec&      aux_S_n,            // 1xT
+    const arma::rowvec& u,                  // 1xT
+    const Rcpp::List&   prior,
+    bool                sample_s_ = true
+);
+
 #endif  // _SV_H_
